Enum Event
#[non_exhaustive]pub enum Event {
FencedRelease {
fence: OwnedFd,
},
ImmediateRelease,
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
FencedRelease
release buffer with fence
Sent when the compositor has finalised its usage of the associated buffer for the relevant commit, providing a dma_fence which will be signaled when all operations by the compositor on that buffer for that commit have finished.
Once the fence has signaled, and assuming the associated buffer is not pending release from other wl_surface.commit requests, no additional explicit or implicit synchronization is required to safely reuse or destroy the buffer.
This event destroys the zwp_linux_buffer_release_v1 object.
This is a destructor, once received this object cannot be used any longer.
ImmediateRelease
release buffer immediately
Sent when the compositor has finalised its usage of the associated buffer for the relevant commit, and either performed no operations using it, or has a guarantee that all its operations on that buffer for that commit have finished.
Once this event is received, and assuming the associated buffer is not pending release from other wl_surface.commit requests, no additional explicit or implicit synchronization is required to safely reuse or destroy the buffer.
This event destroys the zwp_linux_buffer_release_v1 object.
This is a destructor, once received this object cannot be used any longer.
Implementations